guix-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

18/163: gnu: couger: Adjust wrap phase.


From: guix-commits
Subject: 18/163: gnu: couger: Adjust wrap phase.
Date: Mon, 25 Jan 2021 02:01:18 -0500 (EST)

apteryx pushed a commit to branch cu/farewell-to-pythonpath
in repository guix.

commit b2a641d17a768cf64d420f9978a1b534a3ea35a8
Author: Maxim Cournoyer <maxim.cournoyer@gmail.com>
AuthorDate: Fri Jan 22 13:14:24 2021 -0500

    gnu: couger: Adjust wrap phase.
    
    * gnu/packages/bioinformatics.scm (couger): Import the (guix build
    python-build-system) module.
    [phases]: Delete trailing #t.
    {wrap-program}: Use the new Guix PYTHONPATH.
---
 gnu/packages/bioinformatics.scm | 17 ++++++++++-------
 1 file changed, 10 insertions(+), 7 deletions(-)

diff --git a/gnu/packages/bioinformatics.scm b/gnu/packages/bioinformatics.scm
index d224d46..1e2a1b5 100644
--- a/gnu/packages/bioinformatics.scm
+++ b/gnu/packages/bioinformatics.scm
@@ -2239,7 +2239,12 @@ gene predictor designed to work with assembled, aligned 
RNA-seq transcripts.")
                 "04p2b14nmhzxw5h72mpzdhalv21bx4w9b87z0wpw0xzxpysyncmq"))))
     (build-system gnu-build-system)
     (arguments
-     `(#:tests? #f
+     `(#:imported-modules ,(cons '(guix build python-build-system)
+                                 %gnu-build-system-modules)
+       #:modules ((guix build gnu-build-system)
+                  ((guix build python-build-system) #:select (guix-pythonpath))
+                  (guix build utils))
+       #:tests? #f
        #:phases
        (modify-phases %standard-phases
          (delete 'configure)
@@ -2256,17 +2261,15 @@ gene predictor designed to work with assembled, aligned 
RNA-seq transcripts.")
                 (("from argparse")
                  (string-append "import sys\nsys.path.append(\""
                                 out "\")\nfrom argparse")))
-              (install-file "couger" bin))
-            #t))
+              (install-file "couger" bin))))
          (add-after
           'install 'wrap-program
           (lambda* (#:key inputs outputs #:allow-other-keys)
             ;; Make sure 'couger' runs with the correct PYTHONPATH.
             (let* ((out (assoc-ref outputs "out"))
-                   (path (getenv "PYTHONPATH")))
+                   (pythonpath (guix-pythonpath inputs)))
               (wrap-program (string-append out "/bin/couger")
-                `("PYTHONPATH" ":" prefix (,path))))
-            #t)))))
+                `(,pythonpath ":" prefix (,(getenv pythonpath))))))))))
     (inputs
      `(("python" ,python-2)
        ("python2-pillow" ,python2-pillow)
@@ -2256,17 +2261,15 @@ gene predictor designed to work with assembled, aligned 
           'install 'wrap-program
           (lambda* (#:key inputs outputs #:allow-other-keys)
-            ;; Make sure 'couger' runs with the correct PYTHONPATH.
+            ;; Make sure 'couger' runs with the correct Guix PYTHONPATH.
             (let* ((out (assoc-ref outputs "out"))



reply via email to

[Prev in Thread] Current Thread [Next in Thread]